==> kilroy-module-pytorch-py-sdk-0.4.0.tar.gz: kilroy-module-pytorch-py-sdk-0.4.0/src/kilroy_module_pytorch_py_sdk/optimizers/rmsprop.py <==
from dataclasses import dataclass
from typing import Any, Dict

from kilroy_module_server_py_sdk import (
    Configurable,
    SerializableModel,
    background,
    classproperty,
)
from torch.optim import RMSprop

from kilroy_module_pytorch_py_sdk.optimizers.base import (
    Optimizer,
    OptimizerParameter,
)


class Params(SerializableModel):
    lr: float = 0.001
    momentum: float = 0
    alpha: float = 0.99
    eps: float = 1e-8
    weight_decay: float = 0


@dataclass
class State:
    optimizer: RMSprop


class RMSPropOptimizer(Optimizer, Configurable[State]):
    class LrParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class MomentumParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class AlphaParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class EpsParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class WeightDecayParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    async def build_default_state(self) -> State:
        user_params = Params(**self._kwargs)
        return State(optimizer=RMSprop(self._params, **user_params.dict()))

    async def step(self) -> None:
        async with self.state.write_lock() as state:

            def step():
                state.optimizer.step()
                state.optimizer.zero_grad()

            await background(step)

==> kilroy-module-pytorch-py-sdk-0.5.0.tar.gz: kilroy-module-pytorch-py-sdk-0.5.0/src/kilroy_module_pytorch_py_sdk/optimizers/rmsprop.py <==
from dataclasses import dataclass
from pathlib import Path
from typing import Any, Dict

import torch
from kilroy_module_server_py_sdk import (
    Configurable,
    SerializableModel,
    background,
    classproperty,
)
from torch.optim import RMSprop

from kilroy_module_pytorch_py_sdk.optimizers.base import (
    Optimizer,
    OptimizerParameter,
)


class Params(SerializableModel):
    lr: float = 0.001
    momentum: float = 0
    alpha: float = 0.99
    eps: float = 1e-8
    weight_decay: float = 0


@dataclass
class State:
    optimizer: RMSprop


class RMSPropOptimizer(Optimizer, Configurable[State]):
    class LrParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class MomentumParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class AlphaParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class EpsParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    class WeightDecayParameter(OptimizerParameter[State, float]):
        @classproperty
        def schema(cls) -> Dict[str, Any]:
            return {"type": "number", "minimum": 0}

    async def build_default_state(self) -> State:
        model_params = self._kwargs.pop("parameters")
        user_params = Params(**self._kwargs)
        return State(optimizer=RMSprop(model_params, **user_params.dict()))

    @classmethod
    async def save_state(cls, state: State, directory: Path) -> None:
        with open(directory / "optimizer.pt", "wb") as f:
            await background(torch.save, state.optimizer.state_dict(), f)

    async def load_saved_state(self, directory: Path) -> State:
        with open(directory / "optimizer.pt", "rb") as f:
            state_dict = await background(torch.load, f)
        optimizer = RMSprop(self._kwargs.pop("parameters"))
        optimizer.load_state_dict(state_dict)
        return State(optimizer=optimizer)

    async def step(self) -> None:
        async with self.state.write_lock() as state:

            def step():
                state.optimizer.step()
                state.optimizer.zero_grad()

            await background(step)
